==> react-atom-switch-1.19.0.tgz: package/lib/SwitchType/toggle.js <==
import { forwardRef } from 'react';
import cx from 'classnames';
import AtomLabel from '@s-ui/react-atom-label';
import { suitClass, switchClassNames } from './helpers';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export var ToggleSwitchTypeRender = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _cx, _cx2;

  var disabled = _ref.disabled,
      isFitted = _ref.isFitted,
      isFocus = _ref.isFocus,
      isClick = _ref.isClick,
      isToggle = _ref.isToggle,
      label = _ref.label,
      labelLeft = _ref.labelLeft,
      labelOptionalText = _ref.labelOptionalText,
      labelRight = _ref.labelRight,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      onClick = _ref.onClick,
      onKeyDown = _ref.onKeyDown,
      onToggle = _ref.onToggle,
      size = _ref.size,
      type = _ref.type,
      value = _ref.value;
  var isActive = value !== undefined ? value : isToggle;

  var onKeyDownHandler = function onKeyDownHandler(event) {
    onKeyDown(event, isActive);
  };

  return /*#__PURE__*/_jsxs("div", {
    className: switchClassNames(size, type, 'toggleType', isActive, isFocus, isClick, disabled),
    children: [label && /*#__PURE__*/_jsx(AtomLabel, {
      name: name,
      text: label,
      optionalText: labelOptionalText
    }), /*#__PURE__*/_jsxs("div", {
      className: cx(suitClass({
        element: 'container'
      }), (_cx = {}, _cx[suitClass({
        element: 'container--isFitted'
      })] = isFitted, _cx)),
      tabIndex: "0",
      onFocus: onFocus,
      onClick: onClick,
      onBlur: onBlur,
      onKeyDown: onKeyDownHandler,
      ref: ref,
      children: [/*#__PURE__*/_jsx("span", {
        className: cx(suitClass({
          element: 'text'
        }), suitClass({
          element: 'left'
        })),
        onClick: function onClick() {
          return onToggle(false);
        },
        children: labelLeft
      }), /*#__PURE__*/_jsx("div", {
        className: cx(suitClass({
          element: 'inputContainer'
        })),
        onClick: function onClick() {
          return onToggle();
        },
        children: /*#__PURE__*/_jsx("div", {
          className: cx(suitClass({
            element: 'circle'
          }), (_cx2 = {}, _cx2[suitClass({
            modifier: 'toggle'
          })] = isActive, _cx2))
        })
      }), /*#__PURE__*/_jsx("span", {
        className: cx(suitClass({
          element: 'text'
        }), suitClass({
          element: 'right'
        })),
        onClick: function onClick() {
          return onToggle(true);
        },
        children: labelRight
      })]
    })]
  });
});
ToggleSwitchTypeRender.displayName = 'ToggleSwitchTypeRender';

==> react-atom-switch-1.21.0.tgz: package/lib/SwitchType/toggle.js <==
import { forwardRef } from 'react';
import cx from 'classnames';
import AtomLabel from '@s-ui/react-atom-label';
import { suitClass, switchClassNames } from './helpers';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export var ToggleSwitchTypeRender = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _cx, _cx2;

  var disabled = _ref.disabled,
      isFitted = _ref.isFitted,
      isFocus = _ref.isFocus,
      isClick = _ref.isClick,
      isToggle = _ref.isToggle,
      label = _ref.label,
      labelLeft = _ref.labelLeft,
      labelOptionalText = _ref.labelOptionalText,
      labelRight = _ref.labelRight,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      onClick = _ref.onClick,
      onKeyDown = _ref.onKeyDown,
      onToggle = _ref.onToggle,
      size = _ref.size,
      type = _ref.type,
      value = _ref.value,
      fullWidth = _ref.fullWidth;
  var isActive = value !== undefined ? value : isToggle;

  var onKeyDownHandler = function onKeyDownHandler(event) {
    onKeyDown(event, isActive);
  };

  return /*#__PURE__*/_jsxs("div", {
    className: switchClassNames(size, type, 'toggleType', isActive, isFocus, isClick, disabled, fullWidth),
    children: [label && /*#__PURE__*/_jsx(AtomLabel, {
      name: name,
      text: label,
      optionalText: labelOptionalText
    }), /*#__PURE__*/_jsxs("div", {
      className: cx(suitClass({
        element: 'container'
      }), (_cx = {}, _cx[suitClass({
        element: 'container--isFitted'
      })] = isFitted, _cx[suitClass({
        element: 'container--fullWidth'
      })] = fullWidth, _cx)),
      tabIndex: "0",
      onFocus: onFocus,
      onClick: onClick,
      onBlur: onBlur,
      onKeyDown: onKeyDownHandler,
      ref: ref,
      children: [/*#__PURE__*/_jsx("span", {
        className: cx(suitClass({
          element: 'text'
        }), suitClass({
          element: 'left'
        })),
        onClick: function onClick() {
          return onToggle(false);
        },
        children: labelLeft
      }), /*#__PURE__*/_jsx("div", {
        className: cx(suitClass({
          element: 'inputContainer'
        })),
        onClick: function onClick() {
          return onToggle();
        },
        children: /*#__PURE__*/_jsx("div", {
          className: cx(suitClass({
            element: 'circle'
          }), (_cx2 = {}, _cx2[suitClass({
            modifier: 'toggle'
          })] = isActive, _cx2))
        })
      }), /*#__PURE__*/_jsx("span", {
        className: cx(suitClass({
          element: 'text'
        }), suitClass({
          element: 'right'
        })),
        onClick: function onClick() {
          return onToggle(true);
        },
        children: labelRight
      })]
    })]
  });
});
ToggleSwitchTypeRender.displayName = 'ToggleSwitchTypeRender';
